@@ -4,7 +4,7 @@ use App::GHPT::Wrapper::Ourperl;
 
 use v5.20;
 
-our $VERSION = '1.000008';
+our $VERSION = '1.000009';
 
 1;
 
@@ -22,7 +22,7 @@ App::GHPT - A command line tool to simplify using Github and Pivotal Tracker for
 
 =head1 VERSION
 
-version 1.000008
+version 1.000009
 
 =head1 SYNOPSIS
 
@@ -123,6 +123,15 @@ you can configure one or more alternative namespaces by setting the git config
 key C<submit-work.question-namespaces>. This should be a space-separated list
 of namespaces under which questions can live.
 
+=head1 REQUESTER NAME IN PULL REQUESTS
+
+By default, the name of the PT story's requester will be included in the pull
+request text. This is helpful if you relay your project's PRs to Slack, as the
+requester can get alerted when their name is used.
+
+If you want to disable this, set the git config key
+C<submit-work.include-requester-name-in-pr> to C<0>.
+
 =head1 COMMAND LINE OPTIONS
 
 This tool accepts the following options:
@@ -217,17 +226,13 @@ Mark Fowler <mfowler@maxmind.com>
 
 =item *
 
-Patrick Cronin <PatrickCronin@users.noreply.github.com>
-
-=item *
-
 Patrick Cronin <pcronin@maxmind.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by MaxMind, Inc.
+This software is Copyright (c) 2018 by MaxMind, Inc.
 
 This is free software, licensed under:
 
